@@ -9,6 +9,7 @@ class ProjectConfig(TypedDict):
     pred_label: Optional[str]
     feature_exclude: Optional[List[str]]
     drop_duplicate_uid: Optional[bool]
+    handle_errors: Optional[bool]
 
 
 class DataConfig(TypedDict):
@@ -16,6 +17,8 @@ class DataConfig(TypedDict):
     feature_exclude: List[str]
     feature_encodings: Dict[str, str]
     drop_duplicate_uid: bool
+    sample_percentage: float
+    explainability_sample_percentage: float
 
 
 class SyntheticDataConfig(TypedDict):
